.. spatialist documentation master file, created by
   sphinx-quickstart on Wed Mar 28 16:58:10 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to spatialist's documentation!
======================================

.. toctree::

   installation
   spatialist
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

